@@ -318,6 +318,9 @@ pub struct BrowserConfig {
 
     /// Additional command line arguments to pass to the browser instance.
     args: Vec<String>,
+
+    /// Whether to disable DEFAULT_ARGS or not, default is false
+    disable_default_args: bool,
 }
 
 #[derive(Debug, Clone)]
@@ -335,6 +338,7 @@ pub struct BrowserConfigBuilder {
     viewport: Viewport,
     request_timeout: Duration,
     args: Vec<String>,
+    disable_default_args: bool,
 }
 
 impl BrowserConfig {
@@ -363,6 +367,7 @@ impl Default for BrowserConfigBuilder {
             viewport: Default::default(),
             request_timeout: Duration::from_millis(REQUEST_TIMEOUT),
             args: Vec::new(),
+            disable_default_args: false,
         }
     }
 }
@@ -393,6 +398,11 @@ impl BrowserConfigBuilder {
         self
     }
 
+    pub fn port(mut self, port: u16) -> Self {
+        self.port = port;
+        self
+    }
+
     pub fn request_timeout(mut self, timeout: Duration) -> Self {
         self.request_timeout = timeout;
         self
@@ -464,6 +474,11 @@ impl BrowserConfigBuilder {
         self
     }
 
+    pub fn disable_default_args(mut self) -> Self {
+        self.disable_default_args = true;
+        self
+    }
+
     pub fn build(self) -> std::result::Result<BrowserConfig, String> {
         let executable = if let Some(e) = self.executable {
             e
@@ -485,44 +500,30 @@ impl BrowserConfigBuilder {
             viewport: self.viewport,
             request_timeout: self.request_timeout,
             args: self.args,
+            disable_default_args: self.disable_default_args,
         })
     }
 }
 
 impl BrowserConfig {
     pub fn launch(&self) -> io::Result<Child> {
-        let dbg_port = format!("--remote-debugging-port={}", self.port);
-
-        let args = [
-            dbg_port.as_str(),
-            "--disable-background-networking",
-            "--enable-features=NetworkService,NetworkServiceInProcess",
-            "--disable-background-timer-throttling",
-            "--disable-backgrounding-occluded-windows",
-            "--disable-breakpad",
-            "--disable-client-side-phishing-detection",
-            "--disable-component-extensions-with-background-pages",
-            "--disable-default-apps",
-            "--disable-dev-shm-usage",
-            "--disable-extensions",
-            "--disable-features=TranslateUI",
-            "--disable-hang-monitor",
-            "--disable-ipc-flooding-protection",
-            "--disable-popup-blocking",
-            "--disable-prompt-on-repost",
-            "--disable-renderer-backgrounding",
-            "--disable-sync",
-            "--force-color-profile=srgb",
-            "--metrics-recording-only",
-            "--no-first-run",
-            "--enable-automation",
-            "--password-store=basic",
-            "--use-mock-keychain",
-            "--enable-blink-features=IdleDetection",
-        ];
-
         let mut cmd = process::Command::new(&self.executable);
-        cmd.args(&args).args(&DEFAULT_ARGS).args(&self.args).args(
+
+        if self.disable_default_args {
+            cmd.args(&self.args);
+        } else {
+            cmd.args(&DEFAULT_ARGS).args(&self.args);
+        }
+
+        if !self
+            .args
+            .iter()
+            .any(|arg| arg.contains("--remote-debugging-port="))
+        {
+            cmd.arg(format!("--remote-debugging-port={}", self.port));
+        }
+
+        cmd.args(
             self.extensions
                 .iter()
                 .map(|e| format!("--load-extension={}", e)),
@@ -530,6 +531,14 @@ impl BrowserConfig {
 
         if let Some(ref user_data) = self.user_data_dir {
             cmd.arg(format!("--user-data-dir={}", user_data.display()));
+        } else {
+            // If the user did not specify a data directory, this would default to the systems default
+            // data directory. In most cases, we would rather have a fresh instance of Chromium. Specify
+            // a temp dir just for chromiumoxide instead.
+            cmd.arg(format!(
+                "--user-data-dir={}",
+                std::env::temp_dir().join("chromiumoxide-runner").display()
+            ));
         }
 
         if let Some((width, height)) = self.window_size {
@@ -615,7 +624,7 @@ pub(crate) fn get_chrome_path_from_windows_registry() -> Option<std::path::PathB
 
 /// These are passed to the Chrome binary by default.
 /// Via https://github.com/puppeteer/puppeteer/blob/4846b8723cf20d3551c0d755df394cc5e0c82a94/src/node/Launcher.ts#L157
-static DEFAULT_ARGS: [&str; 23] = [
+static DEFAULT_ARGS: [&str; 24] = [
     "--disable-background-networking",
     "--enable-features=NetworkService,NetworkServiceInProcess",
     "--disable-background-timer-throttling",
@@ -639,4 +648,5 @@ static DEFAULT_ARGS: [&str; 23] = [
     "--enable-automation",
     "--password-store=basic",
     "--use-mock-keychain",
+    "--enable-blink-features=IdleDetection",
 ];
